@@ -1,4 +1,4 @@
-__version__ = '0.9.29'
+__version__ = '0.9.40'
 Version = __version__ # for backware compatibility
 
-from vim import Vim
+from vim import Vim, Sms
